@@ -23,10 +23,24 @@ from .gui_structure_classes import FigureOption, Option
 from .gui_structure_classes.functions import check_aim_options, show_linked_options
 
 if TYPE_CHECKING:
+    from collections.abc import Callable
+    from typing import Protocol
+
     from ScenarioGUI.gui_classes.gui_structure import GuiStructure
 
     from .translation_class import Translations
 
+    class ResultsClass(Protocol):
+        """Testing"""
+
+        def to_dict(self) -> dict:
+            """creates a dict from class data"""
+
+        @staticmethod
+        def from_dict(dictionary: dict) -> ResultsClass:
+            """creates a class from dict data"""
+
+
 currentdir = dirname(realpath(__file__))
 parentdir = dirname(currentdir)
 path.append(parentdir)
@@ -48,6 +62,12 @@ class MainWindow(QtW.QMainWindow, BaseUI):
         app: QtW.QApplication,
         gui_structure: type[GuiStructure],
         translations: type[Translations],
+        *,
+        result_creating_class: type[ResultsClass],
+        data_2_results_function: Callable[
+            [DataStorage],
+            tuple[object, ft_partial[[], None]] | tuple[object, Callable[[], None]],
+        ],
     ) -> MainWindow:
         """
 
@@ -57,6 +77,10 @@ class MainWindow(QtW.QMainWindow, BaseUI):
             Q widget as main window where everything is happening
         app : QtW.QApplication
             The widget for the application itself
+        result_creating_class: Object with from_dict and to_dict function
+            results creating class
+        data_2_results_function : Callable
+            function to create the results class and a function to be called in the thread
 
         Returns
         -------
@@ -70,6 +94,9 @@ class MainWindow(QtW.QMainWindow, BaseUI):
         # pyside6-rcc icons.qrc -o icons_rc.py
         self.translations: Translations = translations()  # init translation class
 
+        self.result_creating_class = result_creating_class
+        self.data_2_results_function = data_2_results_function
+
         self.gui_structure = gui_structure(self.central_widget, self.translations)
         [page.create_page(self.central_widget, self.stacked_widget, self.vertical_layout_menu) for page in self.gui_structure.list_of_pages]
 
@@ -90,7 +117,7 @@ class MainWindow(QtW.QMainWindow, BaseUI):
         # check if backup folder exits and otherwise create it
         makedirs(dirname(self.backup_file), exist_ok=True)
         makedirs(dirname(self.default_path), exist_ok=True)
-        for idx, (name, icon, short_cut) in enumerate(zip(self.translations.languages, self.translations.icon, self.translations.short_cut, strict=True)):
+        for idx, (name, icon, short_cut) in enumerate(zip(self.translations.languages, self.translations.icon, self.translations.short_cut)):
             self._create_action_language(idx, name, icon, short_cut)
         # add languages to combo box
         self.gui_structure.option_language.widget.addItems(self.translations.languages)
@@ -99,15 +126,12 @@ class MainWindow(QtW.QMainWindow, BaseUI):
         self.list_widget_scenario.clear()  # reset list widget with stored scenarios
         self.changedFile: bool = False  # set change file variable to false
         self.ax: list = []  # axes of figure
-        self.axBorehole = None
-        self.number_of_scenarios: int = 1  # number of scenarios
-        self.finished: int = 1  # number of finished scenarios
         self.threads: list[CalcProblem] = []  # list of calculation threads
         self.list_ds: list[DataStorage] = []  # list of data storages
-        self.sizeB = QtC.QSize(48, 48)  # size of big logo on push button
-        self.sizeS = QtC.QSize(24, 24)  # size of small logo on push button
-        self.sizePushB = QtC.QSize(150, 75)  # size of big push button
-        self.sizePushS = QtC.QSize(75, 75)  # size of small push button
+        self.size_b = QtC.QSize(48, 48)  # size of big logo on push button
+        self.size_s = QtC.QSize(24, 24)  # size of small logo on push button
+        self.size_push_b = QtC.QSize(150, 75)  # size of big push button
+        self.size_push_s = QtC.QSize(75, 75)  # size of small push button
         # init links from buttons to functions
         self.set_links()
         # set event filter for push button sizing
@@ -127,7 +151,7 @@ class MainWindow(QtW.QMainWindow, BaseUI):
 
         [option.init_links() for option, _ in self.gui_structure.list_of_options]
 
-        globs.LOGGER.info(self.translations.tool_imported[self.gui_structure.option_language.get_value()])
+        globs.LOGGER.info(self.translations.tool_imported[self.gui_structure.option_language.get_value()[0]])
         # allow checking of changes
         self.checking: bool = True
 
@@ -291,15 +315,15 @@ class MainWindow(QtW.QMainWindow, BaseUI):
         button.setText(name)  # set name to button
         # size big or small QPushButton depending on input
         if big:
-            button.setIconSize(self.sizeS)
-            button.setMaximumSize(self.sizePushB)
-            button.setMinimumSize(self.sizePushB)
-            button.resize(self.sizePushB)
+            button.setIconSize(self.size_s)
+            button.setMaximumSize(self.size_push_b)
+            button.setMinimumSize(self.size_push_b)
+            button.resize(self.size_push_b)
             return
-        button.setIconSize(self.sizeB)
-        button.setMaximumSize(self.sizePushS)
-        button.setMinimumSize(self.sizePushS)
-        button.resize(self.sizePushS)
+        button.setIconSize(self.size_b)
+        button.setMaximumSize(self.size_push_s)
+        button.setMinimumSize(self.size_push_s)
+        button.resize(self.size_push_s)
 
     def change(self) -> None:
         """
@@ -346,9 +370,9 @@ class MainWindow(QtW.QMainWindow, BaseUI):
         # get text string of current scenario
         text: str = self.list_widget_scenario.currentItem().text()
         # create current data storage
-        ds: DataStorage = DataStorage(self.gui_structure)
+        d_s: DataStorage = DataStorage(self.gui_structure)
         # check if current data storage is equal to the previous one then delete the *
-        if self.list_ds and ds == self.list_ds[idx]:
+        if self.list_ds and d_s == self.list_ds[idx]:
             if text[-1] != "*":
                 return
             self.list_widget_scenario.item(idx).setText(text[:-1])
@@ -388,7 +412,7 @@ class MainWindow(QtW.QMainWindow, BaseUI):
         def return_2_old_item():
             # change item to old item by thread, because I have not found a direct way which is not lost after
             # return
-            ds = DataStorage(self.gui_structure)
+            d_s = DataStorage(self.gui_structure)
             t = QtC.QTimer(self)
 
             def returning():
@@ -396,7 +420,7 @@ class MainWindow(QtW.QMainWindow, BaseUI):
                 self.checking = False
                 self.list_widget_scenario.setCurrentItem(old_row_item)
                 # set values of selected Datastorage
-                ds.set_values(self.gui_structure)
+                d_s.set_values(self.gui_structure)
                 self.checking = True
                 self.list_widget_scenario.blockSignals(False)
                 t.stop()
@@ -429,9 +453,9 @@ class MainWindow(QtW.QMainWindow, BaseUI):
             # set Icon to question mark icon
             self.dialog.setIcon(QtW.QMessageBox.Question)
             # set label text to leave scenario text depending on language selected
-            self.dialog.setText(self.translations.label_LeaveScenarioText[self.gui_structure.option_language.get_value()])
+            self.dialog.setText(self.translations.label_LeaveScenarioText[self.gui_structure.option_language.get_value()[0]])
             # set window text to  leave scenario text depending on language selected
-            self.dialog.setWindowTitle(self.translations.label_CancelTitle[self.gui_structure.option_language.get_value()])
+            self.dialog.setWindowTitle(self.translations.label_CancelTitle[self.gui_structure.option_language.get_value()[0]])
             # set standard buttons to save, close and cancel
             self.dialog.setStandardButtons(QtW.QMessageBox.Save | QtW.QMessageBox.Close | QtW.QMessageBox.Cancel)
             # get save, close and cancel button
@@ -439,9 +463,9 @@ class MainWindow(QtW.QMainWindow, BaseUI):
             button_cl = self.dialog.button(QtW.QMessageBox.Close)
             button_ca = self.dialog.button(QtW.QMessageBox.Cancel)
             # set save, close and cancel button text depending on language selected
-            button_s.setText(f"{self.translations.push_button_save_scenario[self.gui_structure.option_language.get_value()]} ")
-            button_cl.setText(f"{self.translations.label_LeaveScenario[self.gui_structure.option_language.get_value()]} ")
-            button_ca.setText(f"{self.translations.label_StayScenario[self.gui_structure.option_language.get_value()]} ")
+            button_s.setText(f"{self.translations.push_button_save_scenario[self.gui_structure.option_language.get_value()[0]]} ")
+            button_cl.setText(f"{self.translations.label_LeaveScenario[self.gui_structure.option_language.get_value()[0]]} ")
+            button_ca.setText(f"{self.translations.label_StayScenario[self.gui_structure.option_language.get_value()[0]]} ")
             # set  save, close and cancel button icon
             self.set_push_button_icon(button_s, "Save_Inv")
             self.set_push_button_icon(button_cl, "Exit")
@@ -542,10 +566,10 @@ class MainWindow(QtW.QMainWindow, BaseUI):
 
         # create dialog box to ask for a new name
         self.dialog = QtW.QInputDialog(self.dia)
-        self.dialog.setWindowTitle(self.translations.label_new_scenario[self.gui_structure.option_language.get_value()])
-        self.dialog.setLabelText(f"{self.translations.new_name[self.gui_structure.option_language.get_value()]}{item.text()}")
-        self.dialog.setOkButtonText(self.translations.label_okay[self.gui_structure.option_language.get_value()])  # +++
-        self.dialog.setCancelButtonText(self.translations.label_abort[self.gui_structure.option_language.get_value()])  # +++
+        self.dialog.setWindowTitle(self.translations.label_new_scenario[self.gui_structure.option_language.get_value()[0]])
+        self.dialog.setLabelText(f"{self.translations.new_name[self.gui_structure.option_language.get_value()[0]]}{item.text()}")
+        self.dialog.setOkButtonText(self.translations.label_okay[self.gui_structure.option_language.get_value()[0]])  # +++
+        self.dialog.setCancelButtonText(self.translations.label_abort[self.gui_structure.option_language.get_value()[0]])  # +++
         li = self.dialog.findChildren(QtW.QPushButton)
         self.set_push_button_icon(li[0], "Okay")
         self.set_push_button_icon(li[1], "Abort")
@@ -669,24 +693,24 @@ class MainWindow(QtW.QMainWindow, BaseUI):
 
         # check if list scenario names are not unique
         li_str_match: list[bool] = [
-            self.list_widget_scenario.item(idx).text() == f"{self.translations.scenarioString[self.gui_structure.option_language.get_value()]}: {idx + 1}"
+            self.list_widget_scenario.item(idx).text() == f"{self.translations.scenarioString[self.gui_structure.option_language.get_value()[0]]}: {idx + 1}"
             for idx in range(amount)
         ]
         # update all label, pushButtons, action and Menu names
         for i in [j for j in self.translations.__slots__ if hasattr(self, j)]:
             if isinstance(getattr(self, i), QtW.QMenu):
-                getattr(self, i).setTitle(getattr(self.translations, i)[self.gui_structure.option_language.get_value()])
+                getattr(self, i).setTitle(getattr(self.translations, i)[self.gui_structure.option_language.get_value()[0]])
                 continue
-            getattr(self, i).setText(getattr(self.translations, i)[self.gui_structure.option_language.get_value()])
+            getattr(self, i).setText(getattr(self.translations, i)[self.gui_structure.option_language.get_value()[0]])
         # set translation of toolbox items
-        self.gui_structure.translate(self.gui_structure.option_language.get_value(), self.translations)
+        self.gui_structure.translate(self.gui_structure.option_language.get_value()[0], self.translations)
         for idx, name in enumerate(self.translations.languages):
             self.gui_structure.option_language.widget.setItemText(idx, name)
         # set small PushButtons
         self.check_page_button_layout(False)
         # replace scenario names if they are not unique
         scenarios: list = [
-            f"{self.translations.scenarioString[self.gui_structure.option_language.get_value()]}: {i}"
+            f"{self.translations.scenarioString[self.gui_structure.option_language.get_value()[0]]}: {i}"
             if li_str_match[i - 1]
             else self.list_widget_scenario.item(i - 1).text()
             for i in range(1, amount + 1)
@@ -723,14 +747,14 @@ class MainWindow(QtW.QMainWindow, BaseUI):
             self._load_from_data(self.backup_file)
             # change language to english if no change has happened
             self.checking = False
-            if self.gui_structure.option_language.get_value() == 0:
+            if self.gui_structure.option_language.get_value()[0] == 0:
                 self.change_language()
             self.checking = True
             return
         # change language to english
         self.change_language()
         # show message that no backup file is found
-        globs.LOGGER.error(self.translations.no_backup_file[self.gui_structure.option_language.get_value()])
+        globs.LOGGER.error(self.translations.no_backup_file[self.gui_structure.option_language.get_value()[0]])
 
     def fun_save_auto(self) -> None:
         """
@@ -767,27 +791,26 @@ class MainWindow(QtW.QMainWindow, BaseUI):
             self.list_widget_scenario.clear()
             self.list_widget_scenario.addItems(scenarios)
             self.list_widget_scenario.setCurrentRow(0)
+            self.list_ds[0].set_values(self.gui_structure)
             self.check_results()
-
         try:
             # open file and get data
             with open(location) as file:
                 saving = load(file)
         except FileNotFoundError:
-            globs.LOGGER.error(self.translations.no_file_selected[self.gui_structure.option_language.get_value()])
+            globs.LOGGER.error(self.translations.no_file_selected[self.gui_structure.option_language.get_value()[0]])
             return
 
         # write data to variables
         self.list_ds = []
-        for val, results in zip(saving["values"], saving["results"], strict=True):
-            ds = DataStorage(self.gui_structure)
-            ds.from_dict(val)
+        for val, results in zip(saving["values"], saving["results"]):
+            d_s = DataStorage(self.gui_structure)
+            d_s.from_dict(val)
             if results is None:
-                ds.results = None
+                d_s.results = None
             else:
-                ds.results = globs.ResultsClass()
-                ds.results._from_dict(results)
-            self.list_ds.append(ds)
+                d_s.results = self.result_creating_class.from_dict(results)
+            self.list_ds.append(d_s)
         # set and change the window title
         self.filename = saving["filename"]
         general_changes(saving["names"])
@@ -813,14 +836,14 @@ class MainWindow(QtW.QMainWindow, BaseUI):
             "names": scenario_names,
             "version": globs.VERSION,
             "values": [ds.to_dict() for ds in self.list_ds],
-            "results": [ds.results._to_dict() if ds.results is not None else None for ds in self.list_ds],
+            "results": [ds.results.to_dict() if ds.results is not None else None for ds in self.list_ds],
         }
         try:
             # write data to back up file
             with open(location, "w") as file:
                 dump(saving, file, indent=1)
         except FileNotFoundError:
-            globs.LOGGER.error(self.translations.no_file_selected[self.gui_structure.option_language.get_value()])
+            globs.LOGGER.error(self.translations.no_file_selected[self.gui_structure.option_language.get_value()[0]])
         except PermissionError:  # pragma: no cover
             globs.LOGGER.error("PermissionError")
 
@@ -836,7 +859,7 @@ class MainWindow(QtW.QMainWindow, BaseUI):
         # open interface and get file name
         self.filename = QtW.QFileDialog.getOpenFileName(
             self.central_widget,
-            caption=self.translations.choose_load[self.gui_structure.option_language.get_value()],
+            caption=self.translations.choose_load[self.gui_structure.option_language.get_value()[0]],
             filter=f"{globs.FILE_EXTENSION} (*.{globs.FILE_EXTENSION})",
             dir=str(self.default_path),
         )
@@ -886,7 +909,7 @@ class MainWindow(QtW.QMainWindow, BaseUI):
         if self.filename == MainWindow.filename_default:
             self.filename: tuple = QtW.QFileDialog.getSaveFileName(
                 self.central_widget,
-                caption=self.translations.Save[self.gui_structure.option_language.get_value()],
+                caption=self.translations.Save[self.gui_structure.option_language.get_value()[0]],
                 filter=f"{globs.FILE_EXTENSION} (*.{globs.FILE_EXTENSION})",
                 dir=str(self.default_path),
             )
@@ -954,9 +977,9 @@ class MainWindow(QtW.QMainWindow, BaseUI):
         # deactivate checking for changes
         self.checking: bool = False
         # get selected Datastorage from list
-        ds: DataStorage = self.list_ds[idx]
+        d_s: DataStorage = self.list_ds[idx]
         # set values of selected Datastorage
-        ds.set_values(self.gui_structure)
+        d_s.set_values(self.gui_structure)
         # refresh results if results page is selected
         self.display_results() if self.stacked_widget.currentWidget() == self.gui_structure.page_result.page else None
         # activate checking for changed
@@ -1044,7 +1067,7 @@ class MainWindow(QtW.QMainWindow, BaseUI):
         # append new scenario to List of DataStorages
         self.list_ds.append(DataStorage(self.gui_structure))
         # add new scenario name and item to list widget
-        string = f"{self.translations.scenarioString[self.gui_structure.option_language.get_value()]}: {number + 1}"
+        string = f"{self.translations.scenarioString[self.gui_structure.option_language.get_value()[0]]}: {number + 1}"
         list_of_scenarios = [self.list_widget_scenario.item(x).text().split("*")[0] for x in range(self.list_widget_scenario.count())]
         if string in list_of_scenarios:
             string += "(2)"
@@ -1074,16 +1097,16 @@ class MainWindow(QtW.QMainWindow, BaseUI):
         # show label and progress bar if calculation started otherwise hide them
         self.status_bar_progress_bar.show()
         # calculate percentage of calculated scenario
-        val = val / self.number_of_scenarios
+        val = val / len(self.threads)
         # set percentage to progress bar
         self.progress_bar.setValue(round(val * 100))
         # hide labels and progressBar if all scenarios are calculated
         if isclose(val, 1):
             self.status_bar_progress_bar.hide()
             # show message that calculation is finished
-            globs.LOGGER.info(self.translations.Calculation_Finished[self.gui_structure.option_language.get_value()])
+            globs.LOGGER.info(self.translations.Calculation_Finished[self.gui_structure.option_language.get_value()[0]])
 
-    def thread_function(self, results: tuple[DataStorage, int]) -> None:
+    def thread_function(self, results: tuple[DataStorage, int, CalcProblem]) -> None:
         """
         This function closes the thread of the old calculation and stores it results.
         It increments the number of calculated scenarios, and calls to update the progress bar.
@@ -1099,7 +1122,7 @@ class MainWindow(QtW.QMainWindow, BaseUI):
         None
         """
         # stop finished thread
-        self.threads[self.finished].terminate()
+        results[2].terminate()
 
         try:
             self.list_ds[results[1]] = results[0]
@@ -1107,22 +1130,23 @@ class MainWindow(QtW.QMainWindow, BaseUI):
             return
 
         # count number of finished calculated scenarios
-        self.finished += 1
+        open_threads = [thread for thread in self.threads if not thread.isRunning() and not thread.isFinished()]
+        n_closed_threads = len(self.threads) - len(open_threads)
         # update progress bar
-        self.update_bar(self.finished)
+        self.update_bar(n_closed_threads)
         # if number of finished is the number that has to be calculated enable buttons and actions and change page to
         # results page
-        if self.finished == self.number_of_scenarios:
-            self.push_button_start_multiple.setEnabled(True)
-            self.push_button_start_single.setEnabled(True)
-            self.push_button_save_scenario.setEnabled(True)
-            self.action_start_single.setEnabled(True)
-            self.action_start_multiple.setEnabled(True)
-            self.gui_structure.page_result.button.click()
+        if open_threads:        # start new thread
+            open_threads[0].start()
+            open_threads[0].any_signal.connect(self.thread_function)
             return
-        # start new thread
-        self.threads[self.finished].start()
-        self.threads[self.finished].any_signal.connect(self.thread_function)
+        # display results
+        self.push_button_start_multiple.setEnabled(True)
+        self.push_button_start_single.setEnabled(True)
+        self.push_button_save_scenario.setEnabled(True)
+        self.action_start_single.setEnabled(True)
+        self.action_start_multiple.setEnabled(True)
+        self.gui_structure.page_result.button.click()
 
     def start_multiple_scenarios_calculation(self) -> None:
         """
@@ -1138,10 +1162,9 @@ class MainWindow(QtW.QMainWindow, BaseUI):
         # add scenario if no list of scenarios exits else save current scenario
         self.add_scenario() if not self.list_ds else self.save_scenario()
         # create list of threads with scenarios that have not been calculated
-        self.threads = [CalcProblem(DS, idx) for idx, DS in enumerate(self.list_ds) if DS.results is None]
+        self.threads = [CalcProblem(DS, idx, data_2_results_function=self.data_2_results_function) for idx, DS in enumerate(self.list_ds) if DS.results is None]
         # set number of to calculate scenarios
-        self.number_of_scenarios: int = len(self.threads)
-        if self.number_of_scenarios < 1:
+        if len(self.threads) < 1:
             return
         # disable buttons and actions to avoid two calculation at once
         self.push_button_start_multiple.setEnabled(False)
@@ -1149,15 +1172,12 @@ class MainWindow(QtW.QMainWindow, BaseUI):
         self.push_button_save_scenario.setEnabled(False)
         self.action_start_single.setEnabled(False)
         self.action_start_multiple.setEnabled(False)
-        # initialize finished scenarios counting variable
-        self.finished: int = 0
         # update progress bar
         self.update_bar(0)
         # start calculation if at least one scenario has to be calculated
-        if self.number_of_scenarios > 0:
-            self.threads[0].start()
-            self.threads[0].any_signal.connect(self.thread_function)
-            return
+        for thread in self.threads[:self.gui_structure.option_n_threads.get_value()]:
+            thread.start()
+            thread.any_signal.connect(self.thread_function)
 
     def start_current_scenario_calculation(self, no_run: bool = False) -> None:
         """
@@ -1193,12 +1213,8 @@ class MainWindow(QtW.QMainWindow, BaseUI):
         self.push_button_save_scenario.setEnabled(False)
         self.action_start_single.setEnabled(False)
         self.action_start_multiple.setEnabled(False)
-        # initialize finished scenarios counting variable
-        self.finished = 0
         # create list of threads with calculation to be made
-        self.threads = [CalcProblem(ds, idx)]
-        # set number of to calculate scenarios
-        self.number_of_scenarios = len(self.threads)
+        self.threads = [CalcProblem(ds, idx, data_2_results_function=self.data_2_results_function)]
         # update progress bar
         self.update_bar(0)
         # start calculation
@@ -1226,7 +1242,7 @@ class MainWindow(QtW.QMainWindow, BaseUI):
                 for cat in self.gui_structure.page_result.list_categories:
                     cat.hide(results=True)
                 self.gui_structure.cat_no_result.show()
-                self.gui_structure.text_no_result.set_text(self.translations.not_calculated[self.gui_structure.option_language.get_value()])
+                self.gui_structure.text_no_result.set_text(self.translations.not_calculated[self.gui_structure.option_language.get_value()[0]])
                 return
             update_results()
             for cat in self.gui_structure.page_result.list_categories:
@@ -1241,7 +1257,7 @@ class MainWindow(QtW.QMainWindow, BaseUI):
         # get Datastorage of selected scenario
         ds: DataStorage = self.list_ds[self.list_widget_scenario.currentRow()]
         # get results of selected scenario
-        results: globs.ResultsClass = ds.results
+        results: ResultsClass = ds.results
 
         # set debug message
         if ds.debug_message:
@@ -1314,9 +1330,9 @@ class MainWindow(QtW.QMainWindow, BaseUI):
         # set Icon to question mark icon
         self.dialog.setIcon(QtW.QMessageBox.Question)
         # set label text to cancel text depending on language selected
-        self.dialog.setText(self.translations.label_CancelText[self.gui_structure.option_language.get_value()])
+        self.dialog.setText(self.translations.label_CancelText[self.gui_structure.option_language.get_value()[0]])
         # set window text to cancel text depending on language selected
-        self.dialog.setWindowTitle(self.translations.label_CancelTitle[self.gui_structure.option_language.get_value()])
+        self.dialog.setWindowTitle(self.translations.label_CancelTitle[self.gui_structure.option_language.get_value()[0]])
         # set standard buttons to save, close and cancel
         self.dialog.setStandardButtons(QtW.QMessageBox.Save | QtW.QMessageBox.Close | QtW.QMessageBox.Cancel)
         # get save, close and cancel button
@@ -1324,9 +1340,9 @@ class MainWindow(QtW.QMainWindow, BaseUI):
         button_cl = self.dialog.button(QtW.QMessageBox.Close)
         button_ca = self.dialog.button(QtW.QMessageBox.Cancel)
         # set save, close and cancel button text depending on language selected
-        button_s.setText(f"{self.translations.label_Save[self.gui_structure.option_language.get_value()]} ")
-        button_cl.setText(f"{self.translations.label_close[self.gui_structure.option_language.get_value()]} ")
-        button_ca.setText(f"{self.translations.label_cancel[self.gui_structure.option_language.get_value()]} ")
+        button_s.setText(f"{self.translations.label_Save[self.gui_structure.option_language.get_value()[0]]} ")
+        button_cl.setText(f"{self.translations.label_close[self.gui_structure.option_language.get_value()[0]]} ")
+        button_ca.setText(f"{self.translations.label_cancel[self.gui_structure.option_language.get_value()[0]]} ")
         # set  save, close and cancel button icon
         self.set_push_button_icon(button_s, "Save_Inv")
         self.set_push_button_icon(button_cl, "Exit")
